==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/city/dialogs_es.lua <==

dialogId("vit-hs-vitejteA", "font_statue", "Welcome to the most beautiful city under the sun.")
dialogStr("Bienvenido a la más bella ciudad bajo el sol.")


dialogId("vit-hs-vitejteB", "font_statue", "Welcome to our city - the city of unlimited opportunities.")
dialogStr("Bienvenidos a nuestra ciudad - la ciudad de las oportunidades sin límite.")


dialogId("vit-hs-vitejteC", "font_statue", "On behalf of the citizens of this town I welcome you.")
dialogStr("En nombre de los ciudadanos de esta ciudad, les doy la bienvenida.")


dialogId("vit-hs-vitejteD", "font_statue", "Welcome to our city, whose beauty eclipses that of the gods themselves.")
dialogStr("Bienvenidos a nuestra ciudad, cuya belleza eclipsa la de los mismos dioses.")


dialogId("vit-hs-klid1", "font_statue", "Citizens, please remain calm.")
dialogStr("Ciudadanos, por favor mantengan la calma.")


dialogId("vit-hs-klid2", "font_statue", "There is no imminent danger.")
dialogStr("No hay peligro inminente.")


dialogId("vit-hs-klid3", "font_statue", "The sinking of the northern part of our island is only temporary.")
dialogStr("El hundimiento de la parte norte de nuestra isla es sólo temporal.")


dialogId("vit-hs-klid4", "font_statue", "We have the situation completely under control.")
dialogStr("Tenemos la situación completamente bajo control.")


dialogId("vit-hs-lod0", "font_statue", "The ship from Lemury has now docked at pier #5. This ship continues on to Utopia, Mu and Atlantis.")
dialogStr("La nave desde Lemuria ha atracado en el muelle #5. Esta nave continúa hacia Utopía, Mu y Atlantis.")


dialogId("vit-hs-pojis0", "font_statue", "With First Fishermen Insurance, your house is covered against damage caused by fire, tornadoes, hurricanes, acts of God and dragons` raids. Because fishermen think of everything, choose First Fisherman.")
dialogStr("Con el seguro de Primer Pescador, su casa está cubierta contra el daño causado por fuego, tornados, huracanes, actos de Dios e incursiones de dragones. Porque un pescador piensa en todo, escoja Primer Pescador.")


dialogId("vit-hs-reklama1", "font_statue", "Where are you running?")
dialogStr("¿Donde vas arrancando?")


dialogId("vit-hs-reklama2", "font_white", "To Moon Street. I need to order eight swords.")
dialogStr("Hacia la calle Luna. Necesito encargar ocho espadas.")


dialogId("vit-hs-reklama3", "font_statue", "Why so many swords?")
dialogStr("¿Porqué tantas espadas?")


dialogId("vit-hs-reklama4", "font_white", "You haven`t heard?!? For every eight swords you purchase, you get a pair of bronze earrings absolutely FREE!")
dialogStr("¡¿No haz escuchado?! ¡Por cada ocho espadas que compres, obtienes un par de aros de bronce absolutamente GRATIS!")


dialogId("vit-hs-reklama5", "font_statue", "Wait for me. I`m coming with you!")
dialogStr("¡Espérame, voy contigo!")


dialogId("vit-hs-soud0", "font_statue", "The City Court kindly invites you to the annual town festival of interrogations and executions. Proper attire required.")
dialogStr("La Corte de la Ciudad amablemente le invita al festival anual de las interrogaciones y ejecuciones de la ciudad. Se requiere el traje apropiado.")


dialogId("vit-hs-vodovod0", "font_statue", "The City Council has decided to build an aqueduct, thereby providing direct water service to each home.")
dialogStr("El consejo de la ciudad ha decidido construir un acueducto, el que proveerá servicio directo de agua para cada hogar.")


dialogId("vit-hs-dite0", "font_statue", "Would the mother of the child who got lost on the grounds of city treasury please come to the front desk to pick up his remains.")
dialogStr("¿Podría la madre del niño que se extravió en las salas del tesoro de la ciudad por favor venir a recepción a recoger sus restos?")


dialogId("vit-hs-demoni0", "font_statue", "Citizens, our employees will be stopping by individual homes tomorrow after midnight in order to rid your home of demons and ghosts. We ask that you kindly let them in.")
dialogStr("Ciudadanos, nuestros empleados se detendrán en cada casa mañana después de medianoche para liberarla de demonios y fantasmas. Les solicitamos amablemente dejarlos entrar.")


dialogId("vit-hs-kacir", "font_statue", "Our chief heretic Demikuls will present a lecture this evening in the small auditorium entitled `Do the gods really exist? or Rest assured they cannot harm you!`")
dialogStr("Buestro jefe herético Demíkulo presentará una lectura esta tarde en el pequeño auditorio titulada \"¿Existen realmente los dioses? !o descansa en la seguridad de que no te pueden dañar!\".")


dialogId("vit-hs-jidelna1", "font_statue", "Come visit our seafood restaurant located at the Main Square. Delicious fish specialties and...")
dialogStr("Venga a visitar nuestro restorant de comida marina ubicado en la plaza central. Deliciosas especialidades de pez y ...")


dialogId("vit-hs-jidelna2", "font_statue", "Oh, excuse me.")
dialogStr("Oh, perdón.")


dialogId("vit-m-jakze", "font_small", "What?! A fish restaurant?")
dialogStr("¡¿Qué?! ¿Un restorante de peces?")


dialogId("vit-v-vazne", "font_big", "Are you serious?")
dialogStr("¿Hablas en serio?")


dialogId("vit-m-nechutne", "font_small", "How disgusting!")
dialogStr("¡Que desagradable!")


dialogId("vit-v-nevsimla", "font_big", "That sculpture obviously hasn`t noticed that the city sank a long time ago.")
dialogStr("Esa escultura obviamente no ha notado que la ciudad se hundió hace mucho tiempo atrás")


dialogId("vit-v-automat", "font_big", "It`s probably some kind of automaton. It still thinks that the city is alive.")
dialogStr("Es probablemente una clase de autómata. Todavía piensa que la ciudad está viva.")


dialogId("vit-m-nebo", "font_small", "Or it just can`t face the truth.")
dialogStr("O simplemente no puede enfrentar la verdad.")


dialogId("vit-m-hlava", "font_small", "I`m getting a headache from that head.")
dialogStr("Estoy teniendo una jaqueca por esa cabeza.")


dialogId("vit-v-hlava", "font_big", "That head is giving me a headache.")
dialogStr("Esa cabeza me está dando una jaqueca.")


dialogId("vit-m-nezkusime", "font_small", "Let`s try to shut that head up somehow.")
dialogStr("Tratemos de callar esa cabeza de alguna forma.")


dialogId("vit-v-proc", "font_big", "Why? We`re getting invaluable information about the everyday life of our ancestors.")
dialogStr("¿Porqué? Estamos obteniendo información invaluable acerca de la vida cotidiana de nuestros ancestros.")


dialogId("vit-v-krabi", "font_big", "If we could get all these crabs up near the head...")
dialogStr("Si pudiéramos llevar todos esos cangrejos cerca de la cabeza...")


dialogId("vit-m-tak", "font_small", "...then...?")
dialogStr("¿...entonces...?")


dialogId("vit-v-pockej", "font_big", "Wait, I have to think about it for a moment...")
dialogStr("Espera, tengo que pensarlo por un momento...")


dialogId("vit-m-vecnost", "font_small", "Just imagine - that head has been like doing this all these years...")
dialogStr("Sólo imagina - esa cabeza ha estado de esa forma todos estos años...")


dialogId("vit-v-noa", "font_big", "So what?")
dialogStr("¿Y qué?")


dialogId("vit-m-jak", "font_small", "Well think about how these poor crabs must feel!")
dialogStr("Bueno, ¡Piensa sobre cómo esos pobres cangrejos se deben sentir!")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/city/dialogs_es.lua <==

dialogId("vit-hs-vitejteA", "font_statue", "Welcome to the most beautiful city under the sun.")
dialogStr("Bienvenido a la más bella ciudad bajo el sol.")


dialogId("vit-hs-vitejteB", "font_statue", "Welcome to our city - the city of unlimited opportunities.")
dialogStr("Bienvenidos a nuestra ciudad - la ciudad de las oportunidades sin límite.")


dialogId("vit-hs-vitejteC", "font_statue", "On behalf of the citizens of this town I welcome you.")
dialogStr("En nombre de los ciudadanos de esta ciudad, les doy la bienvenida.")


dialogId("vit-hs-vitejteD", "font_statue", "Welcome to our city, whose beauty eclipses that of the gods themselves.")
dialogStr("Bienvenidos a nuestra ciudad, cuya belleza eclipsa la de los mismos dioses.")


dialogId("vit-hs-klid1", "font_statue", "Citizens, please remain calm.")
dialogStr("Ciudadanos, por favor mantengan la calma.")


dialogId("vit-hs-klid2", "font_statue", "There is no imminent danger.")
dialogStr("No hay peligro inminente.")


dialogId("vit-hs-klid3", "font_statue", "The sinking of the northern part of our island is only temporary.")
dialogStr("El hundimiento de la parte norte de nuestra isla es sólo temporal.")


dialogId("vit-hs-klid4", "font_statue", "We have the situation completely under control.")
dialogStr("Tenemos la situación completamente bajo control.")


dialogId("vit-hs-lod0", "font_statue", "The ship from Lemury has now docked at pier #5. This ship continues on to Utopia, Mu and Atlantis.")
dialogStr("La nave desde Lemuria ha atracado en el muelle #5. Esta nave continúa hacia Utopía, Mu y Atlantis.")


dialogId("vit-hs-pojis0", "font_statue", "With First Fishermen Insurance, your house is covered against damage caused by fire, tornadoes, hurricanes, acts of God and dragons’ raids. Because fishermen think of everything, choose First Fisherman.")
dialogStr("Con el seguro de Primer Pescador, su casa está cubierta contra el daño causado por fuego, tornados, huracanes, actos de Dios e incursiones de dragones. Porque un pescador piensa en todo, escoja Primer Pescador.")


dialogId("vit-hs-reklama1", "font_statue", "Where are you running?")
dialogStr("¿Donde vas arrancando?")


dialogId("vit-hs-reklama2", "font_white", "To Moon Street. I need to order eight swords.")
dialogStr("Hacia la calle Luna. Necesito encargar ocho espadas.")


dialogId("vit-hs-reklama3", "font_statue", "Why so many swords?")
dialogStr("¿Porqué tantas espadas?")


dialogId("vit-hs-reklama4", "font_white", "You haven’t heard?!? For every eight swords you purchase, you get a pair of bronze earrings absolutely FREE!")
dialogStr("¡¿No haz escuchado?! ¡Por cada ocho espadas que compres, obtienes un par de aros de bronce absolutamente GRATIS!")


dialogId("vit-hs-reklama5", "font_statue", "Wait for me. I’m coming with you!")
dialogStr("¡Espérame, voy contigo!")


dialogId("vit-hs-soud0", "font_statue", "The City Court kindly invites you to the annual town festival of interrogations and executions. Proper attire required.")
dialogStr("La Corte de la Ciudad amablemente le invita al festival anual de las interrogaciones y ejecuciones de la ciudad. Se requiere el traje apropiado.")


dialogId("vit-hs-vodovod0", "font_statue", "The City Council has decided to build an aqueduct, thereby providing direct water service to each home.")
dialogStr("El consejo de la ciudad ha decidido construir un acueducto, el que proveerá servicio directo de agua para cada hogar.")


dialogId("vit-hs-dite0", "font_statue", "Would the mother of the child who got lost on the grounds of city treasury please come to the front desk to pick up his remains.")
dialogStr("¿Podría la madre del niño que se extravió en las salas del tesoro de la ciudad por favor venir a recepción a recoger sus restos?")


dialogId("vit-hs-demoni0", "font_statue", "Citizens, our employees will be stopping by individual homes tomorrow after midnight in order to rid your home of demons and ghosts. We ask that you kindly let them in.")
dialogStr("Ciudadanos, nuestros empleados se detendrán en cada casa mañana después de medianoche para liberarla de demonios y fantasmas. Les solicitamos amablemente dejarlos entrar.")


dialogId("vit-hs-kacir", "font_statue", "Our chief heretic Demikuls will present a lecture this evening in the small auditorium entitled ’Do the gods really exist? or Rest assured they cannot harm you!’")
dialogStr("Buestro jefe herético Demíkulo presentará una lectura esta tarde en el pequeño auditorio titulada \"¿Existen realmente los dioses? !o descansa en la seguridad de que no te pueden dañar!\".")


dialogId("vit-hs-jidelna1", "font_statue", "Come visit our seafood restaurant located at the Main Square. Delicious fish specialties and...")
dialogStr("Venga a visitar nuestro restorant de comida marina ubicado en la plaza central. Deliciosas especialidades de pez y ...")


dialogId("vit-hs-jidelna2", "font_statue", "Oh, excuse me.")
dialogStr("Oh, perdón.")


dialogId("vit-m-jakze", "font_small", "What?! A fish restaurant?")
dialogStr("¡¿Qué?! ¿Un restorante de peces?")


dialogId("vit-v-vazne", "font_big", "Are you serious?")
dialogStr("¿Hablas en serio?")


dialogId("vit-m-nechutne", "font_small", "How disgusting!")
dialogStr("¡Que desagradable!")


dialogId("vit-v-nevsimla", "font_big", "That sculpture obviously hasn’t noticed that the city sank a long time ago.")
dialogStr("Esa escultura obviamente no ha notado que la ciudad se hundió hace mucho tiempo atrás")


dialogId("vit-v-automat", "font_big", "It’s probably some kind of automaton. It still thinks that the city is alive.")
dialogStr("Es probablemente una clase de autómata. Todavía piensa que la ciudad está viva.")


dialogId("vit-m-nebo", "font_small", "Or it just can’t face the truth.")
dialogStr("O simplemente no puede enfrentar la verdad.")


dialogId("vit-m-hlava", "font_small", "I’m getting a headache from that head.")
dialogStr("Estoy teniendo una jaqueca por esa cabeza.")


dialogId("vit-v-hlava", "font_big", "That head is giving me a headache.")
dialogStr("Esa cabeza me está dando una jaqueca.")


dialogId("vit-m-nezkusime", "font_small", "Let’s try to shut that head up somehow.")
dialogStr("Tratemos de callar esa cabeza de alguna forma.")


dialogId("vit-v-proc", "font_big", "Why? We’re getting invaluable information about the everyday life of our ancestors.")
dialogStr("¿Porqué? Estamos obteniendo información invaluable acerca de la vida cotidiana de nuestros ancestros.")


dialogId("vit-v-krabi", "font_big", "If we could get all these crabs up near the head...")
dialogStr("Si pudiéramos llevar todos esos cangrejos cerca de la cabeza...")


dialogId("vit-m-tak", "font_small", "...then...?")
dialogStr("¿...entonces...?")


dialogId("vit-v-pockej", "font_big", "Wait, I have to think about it for a moment...")
dialogStr("Espera, tengo que pensarlo por un momento...")


dialogId("vit-m-vecnost", "font_small", "Just imagine - that head has been like doing this all these years...")
dialogStr("Sólo imagina - esa cabeza ha estado de esa forma todos estos años...")


dialogId("vit-v-noa", "font_big", "So what?")
dialogStr("¿Y qué?")


dialogId("vit-m-jak", "font_small", "Well think about how these poor crabs must feel!")
dialogStr("Bueno, ¡Piensa sobre cómo esos pobres cangrejos se deben sentir!")
